<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
<context>
    <name>CustomCommandOptDlg</name>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="97"/>
        <source>Name:</source>
        <translation>Pavadinimas:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="99"/>
        <source>Command:</source>
        <translation>Komanda:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="101"/>
        <source>Shortcuts:</source>
        <translation>Trumpiniai:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="112"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="113"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="213"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="219"/>
        <source>Required</source>
        <translation>Būtina</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="138"/>
        <source>Add Command</source>
        <translation>Pridėti komandą</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="147"/>
        <source>Edit Command</source>
        <translation>Taisyti komandą</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="157"/>
        <source>Delete Command</source>
        <translation>Ištrinti komandą</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="178"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="180"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Pridėti</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="182"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Įrašyti</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="624"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Gerai</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="380"/>
        <source>Please enter a name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="394"/>
        <source>Please enter a command</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="444"/>
        <source>The name already exists,</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="445"/>
        <source>please input another one.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CustomCommandPanel</name>
    <message>
        <location filename="../src/customcommand/customcommandpanel.cpp" line="196"/>
        <source>Add Command</source>
        <translation>Pridėti komandą</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandpanel.cpp" line="200"/>
        <source>No commands yet</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CustomCommandPlugin</name>
    <message>
        <location filename="../src/customcommand/customcommandplugin.cpp" line="35"/>
        <source>Custom commands</source>
        <translation>Tinkintos komandos</translation>
    </message>
</context>
<context>
    <name>CustomCommandSearchRstPanel</name>
    <message>
        <location filename="../src/customcommand/customcommandsearchrstpanel.cpp" line="132"/>
        <source>Search</source>
        <translation>Ieškoti</translation>
    </message>
</context>
<context>
    <name>CustomThemeSettingDialog</name>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="238"/>
        <source>Custom Theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="262"/>
        <source>Style:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="266"/>
        <source>Light</source>
        <translation>Silpnas</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="271"/>
        <source>Dark</source>
        <translation>Tamsi</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="325"/>
        <source>Fore color:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="332"/>
        <source>Back color:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="350"/>
        <source>Prompt PS1:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="354"/>
        <source>Prompt PS2:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="424"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="431"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Patvirtinti</translation>
    </message>
</context>
<context>
    <name>GroupConfigOptDlg</name>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="39"/>
        <source>Group Name(Required)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="41"/>
        <source>Add Group</source>
        <translation>Pridėti grupę</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="44"/>
        <source>Edit Group</source>
        <translation>Taisyti grupę</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="60"/>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="61"/>
        <source>Add</source>
        <translation>Pridėti</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="61"/>
        <source>Save</source>
        <translation>Įrašyti</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="65"/>
        <source>Please enter a group name</source>
        <translation>Įveskite grupės pavadinimą</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="69"/>
        <source>The name should be no more than 30 characters</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ListView</name>
    <message>
        <location filename="../src/views/listview.cpp" line="868"/>
        <source>Delete Server</source>
        <translation>Ištrinti serverį</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="870"/>
        <source>Delete Custom Command</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="873"/>
        <source>Cancel Server Group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="882"/>
        <source>Ungrouped servers will go back to server list!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="498"/>
        <location filename="../src/views/listview.cpp" line="880"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Ar tikrai norite ištrinti %1?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="224"/>
        <location filename="../src/main/mainwindow.cpp" line="276"/>
        <source>New window</source>
        <translation>Naujas langas</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="291"/>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="702"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="704"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Užverti</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1752"/>
        <source>Type path to download file</source>
        <translation>Įveskite kelią atsiunčiamam failui</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="2049"/>
        <source>Custom Theme</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="17"/>
        <source>Copy on select</source>
        <translation>Kopijuoti, žymint tekstą</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="19"/>
        <source>Cursor blink</source>
        <translation>Žymeklio mirksėjimas</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="21"/>
        <source>Cursor style</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="23"/>
        <source>Scroll on keystroke</source>
        <translation>Slinkti paspaudus klavišą</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="25"/>
        <source>Scroll on output</source>
        <translation>Slinkti parodžius išvestį</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="27"/>
        <source>Allow Ctrl+scrollwheel to zoom text size</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="29"/>
        <source>Hide Quake window after losing focus</source>
        <translation>Slėpti Quake langą, jam praradus fokusavimą</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="31"/>
        <source>Quake window animation speed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/service.cpp" line="145"/>
        <location filename="../src/settings/settings_translation.cpp" line="33"/>
        <source>Blur background</source>
        <translation>Sulieti foną</translation>
    </message>
    <message>
        <location filename="../src/main/service.cpp" line="214"/>
        <source>debuginfod URLs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="35"/>
        <source>Use on starting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="37"/>
        <source>Font</source>
        <translation>Šriftas</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="39"/>
        <source>Font size</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/service.cpp" line="176"/>
        <location filename="../src/settings/settings_translation.cpp" line="41"/>
        <source>Opacity</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="43"/>
        <source>Advanced</source>
        <translation>Išplėstinės</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="45"/>
        <source>Cursor</source>
        <translation>Žymeklis</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="47"/>
        <source>Scroll</source>
        <translation>Slinkimas</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="49"/>
        <source>Window</source>
        <translation>Langas</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="51"/>
        <source>Basic</source>
        <translation>Pagrindiniai</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="53"/>
        <source>Interface</source>
        <translation>Sąsaja</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="55"/>
        <source>Shortcuts</source>
        <translation>Trumpiniai</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1594"/>
        <location filename="../src/settings/settings_translation.cpp" line="57"/>
        <source>Others</source>
        <translation>Kita</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1592"/>
        <location filename="../src/main/mainwindow.cpp" line="2183"/>
        <location filename="../src/main/terminalapplication.cpp" line="25"/>
        <location filename="../src/settings/settings_translation.cpp" line="59"/>
        <source>Terminal</source>
        <translation>Terminalas</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="61"/>
        <source>Workspace</source>
        <translation>Darbo sritis</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1658"/>
        <location filename="../src/settings/settings_translation.cpp" line="63"/>
        <source>Custom commands</source>
        <translation>Tinkintos komandos</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1658"/>
        <location filename="../src/settings/settings_translation.cpp" line="65"/>
        <source>Display shortcuts</source>
        <translation>Rodyti sparčiuosius klavišus</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1658"/>
        <location filename="../src/settings/settings_translation.cpp" line="67"/>
        <source>Remote management</source>
        <translation>Nuotolinis administravimas</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1638"/>
        <location filename="../src/settings/settings_translation.cpp" line="101"/>
        <source>New tab</source>
        <translation>Nauja kortelė</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1638"/>
        <location filename="../src/settings/settings_translation.cpp" line="103"/>
        <source>Next tab</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1638"/>
        <location filename="../src/settings/settings_translation.cpp" line="105"/>
        <source>Previous tab</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1640"/>
        <location filename="../src/settings/settings_translation.cpp" line="107"/>
        <source>Select left workspace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1639"/>
        <location filename="../src/settings/settings_translation.cpp" line="109"/>
        <source>Select lower workspace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1640"/>
        <location filename="../src/settings/settings_translation.cpp" line="111"/>
        <source>Select right workspace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1639"/>
        <location filename="../src/settings/settings_translation.cpp" line="113"/>
        <source>Select upper workspace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="119"/>
        <source>Tab titles</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1641"/>
        <location filename="../src/settings/settings_translation.cpp" line="125"/>
        <source>Go to tab 1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1641"/>
        <location filename="../src/settings/settings_translation.cpp" line="127"/>
        <source>Go to tab 2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1641"/>
        <location filename="../src/settings/settings_translation.cpp" line="129"/>
        <source>Go to tab 3</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1642"/>
        <location filename="../src/settings/settings_translation.cpp" line="131"/>
        <source>Go to tab 4</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1642"/>
        <location filename="../src/settings/settings_translation.cpp" line="133"/>
        <source>Go to tab 5</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1642"/>
        <location filename="../src/settings/settings_translation.cpp" line="135"/>
        <source>Go to tab 6</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1643"/>
        <location filename="../src/settings/settings_translation.cpp" line="137"/>
        <source>Go to tab 7</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1643"/>
        <location filename="../src/settings/settings_translation.cpp" line="139"/>
        <source>Go to tab 8</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1643"/>
        <location filename="../src/settings/settings_translation.cpp" line="141"/>
        <source>Go to tab 9</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="143"/>
        <source>Disable flow control using Ctrl+S, Ctrl+Q</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="145"/>
        <source>Shell profile</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="147"/>
        <source>History size</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="149"/>
        <source>Include special character(s) in double click selections</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="151"/>
        <source>Allow Ctrl + left mouse click to set cursor position</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="153"/>
        <source>The HTTP file server used for transmitting debugging information resources</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1658"/>
        <location filename="../src/settings/settings_translation.cpp" line="69"/>
        <location filename="../src/views/tabbar.cpp" line="486"/>
        <location filename="../src/views/tabrenamedlg.cpp" line="208"/>
        <source>Rename title</source>
        <translation>Pervadinti pavadinimą</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1658"/>
        <location filename="../src/settings/settings_translation.cpp" line="71"/>
        <source>Fullscreen</source>
        <translation>Visas ekranas</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="73"/>
        <source>Copy</source>
        <translation>Kopijuoti</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="75"/>
        <source>Default size</source>
        <translation>Numatytasis dydis</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="77"/>
        <source>Paste</source>
        <translation>Įdėti</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="79"/>
        <source>Search</source>
        <translation>Ieškoti</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="81"/>
        <source>Select all</source>
        <translation>Žymėti viską</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="83"/>
        <source>Jump to next command</source>
        <translation>Pereiti prie kitos komandos</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="85"/>
        <source>Jump to previous command</source>
        <translation>Pereiti prie ankstesnės komandos</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="87"/>
        <source>Zoom in</source>
        <translation>Didinti</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="89"/>
        <source>Zoom out</source>
        <translation>Mažinti</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="91"/>
        <source>Close other windows</source>
        <translation>Užverti kitus langus</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1640"/>
        <location filename="../src/settings/settings_translation.cpp" line="93"/>
        <location filename="../src/views/termwidget.cpp" line="499"/>
        <source>Close other workspaces</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1247"/>
        <source>Could not find &quot;%1&quot;, starting &quot;%2&quot; instead. Please check your shell profile.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1253"/>
        <source>Could not open &quot;%1&quot;, unable to run it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1255"/>
        <source>Could not find &quot;%1&quot;, unable to run it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1298"/>
        <source>Output has been suspended by pressing Ctrl+S. Pressing Ctrl+Q to resume.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="95"/>
        <source>Close window</source>
        <translation>Užverti langą</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1640"/>
        <location filename="../src/settings/settings_translation.cpp" line="97"/>
        <location filename="../src/views/termwidget.cpp" line="496"/>
        <source>Close workspace</source>
        <translation>Užverti darbo sritį</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1639"/>
        <location filename="../src/settings/settings_translation.cpp" line="99"/>
        <source>Horizontal split</source>
        <translation>Horizontalus dalijimas</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1639"/>
        <location filename="../src/settings/settings_translation.cpp" line="115"/>
        <source>Vertical split</source>
        <translation>Vertikalus dalijimas</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="117"/>
        <source>Find</source>
        <translation>Rasti</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="263"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="627"/>
        <location filename="../src/main/service.cpp" line="416"/>
        <source>please set another one.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/terminalapplication.cpp" line="28"/>
        <source>Terminal is an advanced terminal emulator with workspace, multiple windows, remote management, quake mode and other features.</source>
        <translation>Terminalas yra išplėstinis terminalo emuliatorius su darbo sričių, kelių langų, nuotolinio administravimo, quake veiksenos ir kitomis ypatybėmis.</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1590"/>
        <source>Tabs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1638"/>
        <location filename="../src/views/tabbar.cpp" line="480"/>
        <source>Close tab</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1639"/>
        <source>Select tab</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1610"/>
        <source>Switch focus to &quot;+&quot; icon</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="157"/>
        <location filename="../src/main/mainwindow.cpp" line="1698"/>
        <source>Select file to upload</source>
        <translation>Pasirinkti failą įkėlimui</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="162"/>
        <location filename="../src/main/mainwindow.cpp" line="1705"/>
        <source>Upload</source>
        <translation>Įkelti</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="230"/>
        <source>Programs are still running in terminal</source>
        <translation>Terminale yra vis dar veikiančių programų</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="182"/>
        <location filename="../src/common/utils.cpp" line="216"/>
        <source>Close this terminal?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="183"/>
        <location filename="../src/common/utils.cpp" line="217"/>
        <source>There is still a process running in this terminal. Closing the terminal will terminate it.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="187"/>
        <location filename="../src/common/utils.cpp" line="221"/>
        <source>There are still %1 processes running in this terminal. Closing the terminal will terminate all of them.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="192"/>
        <location filename="../src/common/utils.cpp" line="212"/>
        <source>Close this window?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="193"/>
        <location filename="../src/common/utils.cpp" line="213"/>
        <source>There are still processes running in this window. Closing the window will terminate all of them.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="136"/>
        <location filename="../src/main/mainwindow.cpp" line="1768"/>
        <source>Select a directory to save the file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="230"/>
        <source>Are you sure you want to uninstall it?</source>
        <translation>Ar tikrai norite ją pašalinti?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="243"/>
        <location filename="../src/common/utils.cpp" line="247"/>
        <source>Are you sure you want to uninstall this application?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="244"/>
        <location filename="../src/common/utils.cpp" line="248"/>
        <source>You will not be able to use Terminal any longer.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="253"/>
        <location filename="../src/views/listview.cpp" line="499"/>
        <location filename="../src/views/listview.cpp" line="893"/>
        <location filename="../src/views/tabrenamedlg.cpp" line="241"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="254"/>
        <location filename="../src/common/utils.cpp" line="298"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Gerai</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="338"/>
        <source>Execute a command in the terminal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="341"/>
        <source>Run script string in the terminal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="332"/>
        <source>Set the work directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="335"/>
        <source>Set the window mode on starting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="344"/>
        <source>Run in quake mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="347"/>
        <source>Keep terminal open when command finishes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="387"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="476"/>
        <source>The name should be no more than 32 characters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="142"/>
        <location filename="../src/main/mainwindow.cpp" line="1774"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="546"/>
        <source>Select</source>
        <translation>Pasirinkti</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="542"/>
        <source>Select the private key file</source>
        <translation>Pasirinkite privačiojo rakto failą</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="121"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="111"/>
        <source>Tab title format</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="123"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="113"/>
        <source>Remote tab title format</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1638"/>
        <location filename="../src/views/tabbar.cpp" line="483"/>
        <source>Close other tabs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="894"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="500"/>
        <location filename="../src/views/tabrenamedlg.cpp" line="245"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Patvirtinti</translation>
    </message>
</context>
<context>
    <name>RemoteManagementPanel</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementpanel.cpp" line="210"/>
        <source>Add Group</source>
        <translation>Pridėti grupę</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/remotemanagementpanel.cpp" line="211"/>
        <source>Add Server</source>
        <translation>Pridėti serverį</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/remotemanagementpanel.cpp" line="215"/>
        <source>No servers yet</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RemoteManagementPlugin</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementplugn.cpp" line="75"/>
        <source>Remote management</source>
        <translation>Nuotolinis administravimas</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/remotemanagementplugn.cpp" line="201"/>
        <source>Make sure that rz and sz commands have been installed in the server before right clicking to upload and download files.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RemoteManagementSearchPanel</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementsearchpanel.cpp" line="211"/>
        <source>Search</source>
        <translation>Ieškoti</translation>
    </message>
</context>
<context>
    <name>ServerConfigManager</name>
    <message>
        <location filename="../src/remotemanage/serverconfigmanager.cpp" line="87"/>
        <source>Groups</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigmanager.cpp" line="88"/>
        <source>Servers</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ServerConfigOptDlg</name>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="91"/>
        <source>Add Server</source>
        <translation>Pridėti serverį</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="127"/>
        <source>Server name:</source>
        <translation>Serverio pavadinimas:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="129"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="139"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="167"/>
        <source>Required</source>
        <translation>Būtina</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="137"/>
        <source>Address:</source>
        <translation>Adresas:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="144"/>
        <source>Port:</source>
        <translation>Prievadas:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="165"/>
        <source>Username:</source>
        <translation>Naudotojo vardas:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="172"/>
        <source>Password:</source>
        <translation>Slaptažodis:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="178"/>
        <source>Certificate:</source>
        <translation>Liudijimas:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="185"/>
        <source>Group:</source>
        <translation>Grupė:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="189"/>
        <source>No Group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="193"/>
        <source>Path:</source>
        <translation>Kelias:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="199"/>
        <source>Command:</source>
        <translation>Komanda:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="205"/>
        <source>Encoding:</source>
        <translation>Koduotė:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="211"/>
        <source>Backspace key:</source>
        <translation>Naikinimo klavišas:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="217"/>
        <source>Delete key:</source>
        <translation>Šalinimo klavišas:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="223"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="224"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Pridėti</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="228"/>
        <source>Edit Server</source>
        <translation>Redaguoti serverį</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="229"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Įrašyti</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="470"/>
        <source>Please enter a server name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="483"/>
        <source>Please enter an IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="488"/>
        <source>Please enter a port</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="494"/>
        <source>Please enter a username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="508"/>
        <source>The server name already exists,</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="509"/>
        <source>please input another one. </source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Service</name>
    <message>
        <location filename="../src/main/service.cpp" line="412"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Gerai</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../src/settings/settings.cpp" line="130"/>
        <source>Split screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="130"/>
        <source>Fullscreen</source>
        <translation>Visas ekranas</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="130"/>
        <source>Normal window</source>
        <translation>Normalus langas</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="130"/>
        <source>Maximum</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="722"/>
        <source>Fast</source>
        <translation>Greitas</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="726"/>
        <source>Slow</source>
        <translation>Lėtas</translation>
    </message>
</context>
<context>
    <name>ShortcutManager</name>
    <message>
        <location filename="../src/settings/shortcutmanager.cpp" line="268"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="277"/>
        <source>The shortcut %1 is invalid, </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings/shortcutmanager.cpp" line="284"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="291"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="297"/>
        <source>The shortcut %1 was already in use, </source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TabRenameWidget</name>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="42"/>
        <source>Insert</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="74"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="88"/>
        <source>username: %u</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="74"/>
        <source>username@: %U</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="74"/>
        <source>remote host: %h</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="75"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="87"/>
        <source>session number: %#</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="75"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="89"/>
        <source>title set by shell: %w</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="86"/>
        <source>program name: %n</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="86"/>
        <source>current directory (short): %d</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="87"/>
        <source>current directory (long): %D</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="88"/>
        <source>local host: %h</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TermWidget</name>
    <message>
        <location filename="../src/views/termwidget.cpp" line="469"/>
        <source>Copy</source>
        <translation>Kopijuoti</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="472"/>
        <source>Paste</source>
        <translation>Įdėti</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="481"/>
        <source>Open</source>
        <translation>Atverti</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="485"/>
        <source>Open in file manager</source>
        <translation>Atverti failų tvarkytuvėje</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="490"/>
        <location filename="../src/views/termwidget.cpp" line="549"/>
        <source>Horizontal split</source>
        <translation>Horizontalus dalijimas</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="492"/>
        <location filename="../src/views/termwidget.cpp" line="549"/>
        <source>Vertical split</source>
        <translation>Vertikalus dalijimas</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="503"/>
        <location filename="../src/views/termwidget.cpp" line="549"/>
        <source>New tab</source>
        <translation>Nauja kortelė</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="510"/>
        <source>Exit fullscreen</source>
        <translation>Išeiti iš viso ekrano</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="512"/>
        <source>Fullscreen</source>
        <translation>Visas ekranas</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="515"/>
        <source>Find</source>
        <translation>Rasti</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="519"/>
        <source>Search</source>
        <translation>Ieškoti</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="529"/>
        <source>Encoding</source>
        <translation>Koduotė</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="531"/>
        <source>Custom commands</source>
        <translation>Tinkintos komandos</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="533"/>
        <source>Remote management</source>
        <translation>Nuotolinis administravimas</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="537"/>
        <source>Upload file</source>
        <translation>Įkelti failą</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="538"/>
        <source>Download file</source>
        <translation>Atsisiųsti failą</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="543"/>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1200"/>
        <source>The debuginfod settings will be effective after restart</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/common/utils.cpp" line="198"/>
        <location filename="../src/common/utils.cpp" line="232"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="200"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Užverti</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="233"/>
        <location filename="../src/common/utils.cpp" line="265"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Gerai</translation>
    </message>
</context>
</TS>